==> stependous_0.81_src.zip: resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Visual C++ generated include file.
// Used by ddr_dwi_creator.rc
//
#define IDM_ABOUTBOX                    0x0010
#define IDD_ABOUTBOX                    100
#define IDS_ABOUTBOX                    101
#define IDD_DDR_DWI_CREATOR_DIALOG      102
#define IDR_HTML_PLEASEWAITDLG          103
#define IDR_MAINFRAME                   128
#define IDR_MENU1                       130
#define IDR_ACCELERATOR1                131
#define IDR_WAVE_PLINK                  132
#define IDB_BITMAP_ARROW_GRID           143
#define IDB_BITMAP_ARROW_GRID_INVERSE   144
#define IDD_DIALOG_PLEASEWAIT           145
#define IDB_BITMAP_SCROLLUP             146
#define IDB_BITMAP_SCROLLDOWN           147
#define IDB_BITMAP1                     148
#define IDI_ICONMAIN                    149
#define IDR_MENU_CUSTOMFLOAT            150
#define IDC_MEDIAPLAYER1                1001
#define IDC_STATIC_BPM                  1005
#define IDC_STATIC_ELAPSEDSECS          1006
#define IDC_STATIC_LAST_HIT             1007
#define IDC_EDIT1                       1008
#define IDC_EDIT_BPM                    1010
#define IDC_SPIN_BPM2                   1011
#define IDC_EDIT_GAP                    1012
#define IDC_SPIN_GAP                    1013
#define IDC_BTN_PLUSGAP                 1014
#define IDC_BTN_MINUS_GAP               1015
#define IDC_CUSTOM1                     1016
#define IDC_BTN_SONGSPEED05             1017
#define IDC_BTN_SONGSPEED_075           1018
#define IDC_BTN_SONGSPEED_10            1019
#define IDC_BTN_SONGSPEED_15            1020
#define IDC_ED_SONGSPEED                1021
#define IDC_SPIN_SONGSPEED              1022
#define IDC_EDIT_TITLE                  1023
#define IDC_EDIT_ARTIST                 1024
#define IDC_COMBO_DIFFICULTY            1025
#define IDC_COMBO_FOOTRATING            1026
#define IDC_EDIT_RANGESTART             1027
#define IDC_EDIT_RANGEEND               1028
#define IDC_COMBO3                      1029
#define IDC_BUTTON_DOIT                 1030
#define IDC_EDIT_JUMPPROB               1031
#define IDC_SPIN_JUMPPROB               1032
#define IDC_EDIT_JUMPSTRING             1033
#define IDC_EDIT_INFO                   1033
#define IDC_SPIN_JUMPSTRING             1034
#define IDC_BUTTON_BPMDOUBLE            1035
#define IDC_BUTTON_BPMHALF              1036
#define IDC_STATIC_CALCBPM              1038
#define IDC_EDIT_SAMPLESTART            1039
#define IDC_BUTTON_SET_SAMPLE_START     1040
#define IDC_EDIT_SAMPLEEND              1041
#define IDC_BUTTON_SET_SAMPLE_END       1042
#define ID_FILE_OPEN32771               32771
#define ID_FILE_SAVE32772               32772
#define ID_FILE_SAVEAS                  32773
#define ID_ACCELERATOR_CTRLO            32774
#define ID_FILE_IMPORTDWIFILE           32776
#define ID_OPTIONS                      32777
#define ID_OPTIONS_PLAYMETRONOMESOUND   32778
#define ID_MODE_TAPTEMPO                32779
#define ID_MODE_STEPDATAINPUT           32780
#define ID_ABOUTCMD                     32782
#define ID_TOP_SETRANGESTART            32783
#define ID_STEPOPTIONS_SETRANGEENDATTHISSTEP 32784

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        151
#define _APS_NEXT_COMMAND_VALUE         32785
#define _APS_NEXT_CONTROL_VALUE         1041
#define _APS_NEXT_SYMED_VALUE           104
#endif
#endif

==> stependous_0.82_src.zip: resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Visual C++ generated include file.
// Used by ddr_dwi_creator.rc
//
#define IDM_ABOUTBOX                    0x0010
#define IDD_ABOUTBOX                    100
#define IDS_ABOUTBOX                    101
#define IDD_DDR_DWI_CREATOR_DIALOG      102
#define IDR_HTML_PLEASEWAITDLG          103
#define IDR_MAINFRAME                   128
#define IDR_MENU1                       130
#define IDR_ACCELERATOR1                131
#define IDR_WAVE_PLINK                  132
#define IDB_BITMAP_ARROW_GRID           143
#define IDB_BITMAP_ARROW_GRID_INVERSE   144
#define IDD_DIALOG_PLEASEWAIT           145
#define IDB_BITMAP_SCROLLUP             146
#define IDB_BITMAP_SCROLLDOWN           147
#define IDB_BITMAP1                     148
#define IDI_ICONMAIN                    149
#define IDR_MENU_CUSTOMFLOAT            150
#define IDC_MEDIAPLAYER1                1001
#define IDC_STATIC_BPM                  1005
#define IDC_STATIC_ELAPSEDSECS          1006
#define IDC_STATIC_LAST_HIT             1007
#define IDC_EDIT1                       1008
#define IDC_EDIT_BPM                    1010
#define IDC_SPIN_BPM2                   1011
#define IDC_EDIT_GAP                    1012
#define IDC_SPIN_GAP                    1013
#define IDC_BTN_PLUSGAP                 1014
#define IDC_BTN_MINUS_GAP               1015
#define IDC_CUSTOM1                     1016
#define IDC_BTN_SONGSPEED05             1017
#define IDC_BTN_SONGSPEED_075           1018
#define IDC_BTN_SONGSPEED_10            1019
#define IDC_BTN_SONGSPEED_15            1020
#define IDC_ED_SONGSPEED                1021
#define IDC_SPIN_SONGSPEED              1022
#define IDC_EDIT_TITLE                  1023
#define IDC_EDIT_ARTIST                 1024
#define IDC_COMBO_DIFFICULTY            1025
#define IDC_COMBO_FOOTRATING            1026
#define IDC_EDIT_RANGESTART             1027
#define IDC_EDIT_RANGEEND               1028
#define IDC_COMBO3                      1029
#define IDC_BUTTON_DOIT                 1030
#define IDC_EDIT_JUMPPROB               1031
#define IDC_SPIN_JUMPPROB               1032
#define IDC_EDIT_JUMPSTRING             1033
#define IDC_EDIT_INFO                   1033
#define IDC_SPIN_JUMPSTRING             1034
#define IDC_BUTTON_BPMDOUBLE            1035
#define IDC_BUTTON_BPMHALF              1036
#define IDC_STATIC_CALCBPM              1038
#define IDC_EDIT_SAMPLESTART            1039
#define IDC_BUTTON_SET_SAMPLE_START     1040
#define IDC_EDIT_SAMPLEEND              1041
#define IDC_BUTTON_SEND_EMAIL           1041
#define IDC_BUTTON_SET_SAMPLE_END       1042
#define ID_FILE_OPEN32771               32771
#define ID_FILE_SAVE32772               32772
#define ID_FILE_SAVEAS                  32773
#define ID_ACCELERATOR_CTRLO            32774
#define ID_FILE_IMPORTDWIFILE           32776
#define ID_OPTIONS                      32777
#define ID_OPTIONS_PLAYMETRONOMESOUND   32778
#define ID_MODE_TAPTEMPO                32779
#define ID_MODE_STEPDATAINPUT           32780
#define ID_ABOUTCMD                     32782
#define ID_TOP_SETRANGESTART            32783
#define ID_STEPOPTIONS_SETRANGEENDATTHISSTEP 32784
#define ID_OPTIONS_METRONOMESOUNDATEACHBEAT 32785
#define ID_OPTIONS_METRONOMESOUNDONLYONSTEPARROWS 32786

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        151
#define _APS_NEXT_COMMAND_VALUE         32787
#define _APS_NEXT_CONTROL_VALUE         1042
#define _APS_NEXT_SYMED_VALUE           104
#endif
#endif
